onPrevious property

VoidCallback? onPrevious
final

Steps back a page. Null disables the chevron — upstream keeps an out-of-bounds chevron focusable rather than removing it, so focus is not lost when it becomes disabled after a click.

Implementation

final VoidCallback? onPrevious;