outOfPageForegroundColor property

WidgetStateProperty<Color?>? outOfPageForegroundColor
final

Label colour of a cell belonging to an adjacent month or decade.

A separate token, never a dimmed cellForegroundColor: Fluent ships an explicit ramp for this and computing one with opacity would be the wrong value in high contrast.

Implementation

final WidgetStateProperty<Color?>? outOfPageForegroundColor;