padding property
Inset between the calendar surface and its header and grid.
Implementation
final WidgetStateProperty<EdgeInsetsGeometry?>? padding;
Inset between the calendar surface and its header and grid.
final WidgetStateProperty<EdgeInsetsGeometry?>? padding;