FluentCalendarView enum

Which of the three grids a FluentCalendar is showing.

The single design axis: it is the only thing resolveFluentCalendarStyle branches on, because it is the only thing that changes cell geometry.

Inheritance
Available extensions

Values

month → const FluentCalendarView

Days of one month, seven columns wide.

year → const FluentCalendarView

The twelve months of one year, four columns wide.

decade → const FluentCalendarView

Twelve consecutive years, four columns wide.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FluentCalendarView>
A constant List of the values in this enum, in order of their declaration.