style property
Style layered over the derived defaults and the nearest FluentHorizontalBarChartTheme.
Implementation
final FluentHorizontalBarChartStyle? style;
Style layered over the derived defaults and the nearest FluentHorizontalBarChartTheme.
final FluentHorizontalBarChartStyle? style;