FluentListItemSize enum
Row height and title type ramp. Figma's Size axis.
Values
- small → const FluentListItemSize
-
24 high on one line, 48 on two.
caption1title on one line. - medium → const FluentListItemSize
-
32 high on one line, 56 on two. The default.
body1title.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FluentListItemSize> - A constant List of the values in this enum, in order of their declaration.