FluentRatingColor enum
Which colour family the shapes take. Figma's Rating color collection.
Values
- neutral → const FluentRatingColor
-
Neutral foreground. The default.
- brand → const FluentRatingColor
-
The brand ramp.
- marigold → const FluentRatingColor
-
The marigold palette family — the conventional "gold star".
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FluentRatingColor> - A constant List of the values in this enum, in order of their declaration.