thumbColor property
Thumb fill. Upstream paints it with the indicator's color, which is why
it transitions on the same spec as the track.
Implementation
final WidgetStateProperty<Color?>? thumbColor;
Thumb fill. Upstream paints it with the indicator's color, which is why
it transitions on the same spec as the track.
final WidgetStateProperty<Color?>? thumbColor;