kMarkerMinPixel top-level constant
double
const kMarkerMinPixel
Lower bound of the categorical marker pixel range (utilities.ts:2338).
Implementation
const double kMarkerMinPixel = 4;
Lower bound of the categorical marker pixel range (utilities.ts:2338).
const double kMarkerMinPixel = 4;