FluentChartAnnotationSemantics class
Accessible naming for one annotation.
Ports ChartAnnotationAccessibilityProps
(types/ChartAnnotation.ts:107-114).
- Annotations
Constructors
- FluentChartAnnotationSemantics({String? label, String? describedBy, String role = 'note'})
-
Creates an annotation's accessible naming.
const
Properties
- describedBy → String?
-
The id of an element describing this annotation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
The announced label.
final
- role → String
-
The ARIA role.
'note'is what the layer applies when the caller names none (types/ChartAnnotation.ts:113).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited